@@ -57,7 +57,6 @@
 #define KEY_BACKGROUND_COLOR  "background_color"
 #define KEY_CONFIGURATION     "configuration"
 #define KEY_ENABLE_SOUND      "enable_sound"
-#define KEY_ENABLE_SPLATS     "enable_splats"
 #define KEY_SAFE_MOVES        "use_safe_moves"
 #define KEY_SHOW_TOOLBAR      "show_toolbar"
 #define KEY_SUPER_SAFE_MOVES  "use_super_safe_moves"
@@ -78,7 +77,6 @@ struct _GnobotsProperties {
   gboolean safe_moves;
   gboolean super_safe_moves;
   gboolean sound;
-  gboolean splats;
   gboolean show_toolbar;
   GdkColor bgcolour;
   gint selected_config;
@@ -118,7 +116,6 @@ static void pmap_selection (GtkWidget *, gpointer);
 static void type_selection (GtkWidget *, gpointer);
 static void safe_cb (GtkWidget *, gpointer);
 static void sound_cb (GtkWidget *, gpointer);
-static void splat_cb (GtkWidget *, gpointer);
 static void defkey_cb (GtkWidget *, gpointer);
 static void fill_typemenu (GtkWidget *);
 static void conf_set_background_color (GdkColor * c);
@@ -216,11 +213,14 @@ pmap_selection (GtkWidget * widget, gpointer data)
 static void
 type_selection (GtkWidget * widget, gpointer data)
 {
+  gchar *config;
   gint num = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 
   properties.selected_config = num;
 
-  conf_set_configuration (game_config_name (properties.selected_config));
+  config = game_config_name (properties.selected_config);
+  conf_set_configuration (config);
+  g_free (config);
 
   set_game_config (properties.selected_config);
 
@@ -239,7 +239,7 @@ type_selection (GtkWidget * widget, gpointer data)
 static void
 safe_cb (GtkWidget * widget, gpointer data)
 {
-  properties.safe_moves = GTK_TOGGLE_BUTTON (widget)->active;
+  properties.safe_moves = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
   conf_set_use_safe_moves (properties.safe_moves);
 }
 
@@ -255,7 +255,7 @@ safe_cb (GtkWidget * widget, gpointer data)
 static void
 super_safe_cb (GtkWidget * widget, gpointer data)
 {
-  properties.super_safe_moves = GTK_TOGGLE_BUTTON (widget)->active;
+  properties.super_safe_moves = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
   conf_set_use_super_safe_moves (properties.super_safe_moves);
 }
 
@@ -271,28 +271,12 @@ super_safe_cb (GtkWidget * widget, gpointer data)
 static void
 sound_cb (GtkWidget * widget, gpointer data)
 {
-  properties.sound = GTK_TOGGLE_BUTTON (widget)->active;
+  properties.sound = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
   games_sound_enable (properties.sound);
   conf_set_enable_sound (properties.sound);
 }
 
 
-/**
- * splat_cb
- * @widget: widget
- * @data: callback data
- *
- * Description:
- * handles message from the 'splat' checkbox
- **/
-static void
-splat_cb (GtkWidget * widget, gpointer data)
-{
-  properties.splats = GTK_TOGGLE_BUTTON (widget)->active;
-  conf_set_enable_splats (properties.splats);
-}
-
-
 /**
  * defkey_cb
  * @widget: widget
@@ -326,6 +310,7 @@ static void
 fill_typemenu (GtkWidget * menu)
 {
   gint i;
+  gchar *config;
 
 #if 0
   /* this is just a place holder so that xgettext can found the strings to
@@ -341,7 +326,9 @@ fill_typemenu (GtkWidget * menu)
 #endif
 
   for (i = 0; i < num_game_configs (); ++i) {
-    gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _(game_config_name (i)));
+    config = game_config_name (i);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _(config));
+    g_free (config);
   }
 
   gtk_combo_box_set_active (GTK_COMBO_BOX (menu), properties.selected_config);
@@ -363,7 +350,7 @@ make_theme_menu (void)
   if (theme_list)
     g_object_unref (theme_list);
 
-  pixmapdir = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  pixmapdir = games_runtime_get_directory (GAMES_RUNTIME_GAME_THEME_DIRECTORY);
   theme_list = games_file_list_new_images (pixmapdir, NULL);
   games_file_list_transform_basename (theme_list);
 
@@ -442,15 +429,15 @@ show_properties_dialog (void)
 					 NULL);
   gtk_dialog_set_has_separator (GTK_DIALOG (propbox), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (propbox)->vbox), 2);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (propbox))), 2);
   /* Set up notebook and add it to hbox of the gtk_dialog */
   g_signal_connect (G_OBJECT (propbox), "destroy",
 		    G_CALLBACK (gtk_widget_destroyed), &propbox);
 
   notebook = gtk_notebook_new ();
   gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propbox)->vbox), notebook,
-		      TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (propbox))),
+              notebook, TRUE, TRUE, 0);
 
   /* The configuration page */
   cpage = gtk_vbox_new (FALSE, 18);
@@ -476,17 +463,12 @@ show_properties_dialog (void)
   vbox = gtk_vbox_new (TRUE, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-  table = gtk_table_new (2, 2, FALSE);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-  gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
-
   chkbox = gtk_check_button_new_with_mnemonic (_("_Use safe moves"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox),
 				properties.safe_moves);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
 		    (GCallback) safe_cb, NULL);
-  gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), chkbox, TRUE, TRUE, 0);
   gtk_widget_set_tooltip_text (chkbox,
                                _("Prevent accidental moves that result in getting killed."));
 
@@ -495,27 +477,23 @@ show_properties_dialog (void)
 				properties.super_safe_moves);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
 		    (GCallback) super_safe_cb, NULL);
-  gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), chkbox, TRUE, TRUE, 0);
   gtk_widget_set_tooltip_text (chkbox,
                                _("Prevents all moves that result in getting killed."));
 
+  frame = games_frame_new (_("Sound"));
+  gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
+  vbox = gtk_vbox_new (TRUE, 6);
+  gtk_container_add (GTK_CONTAINER (frame), vbox);
+
   chkbox = gtk_check_button_new_with_mnemonic (_("_Enable sounds"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.sound);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
 		    (GCallback) sound_cb, NULL);
-  gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), chkbox, TRUE, TRUE, 0);
   gtk_widget_set_tooltip_text (chkbox,
                                _("Play sounds for events like winning a level and dying."));
 
-  chkbox = gtk_check_button_new_with_mnemonic (_("E_nable splats"));
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox),
-				properties.splats);
-  g_signal_connect (G_OBJECT (chkbox), "clicked", (GCallback) splat_cb,
-		    NULL);
-  gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
-  gtk_widget_set_tooltip_text (chkbox,
-                               _("Play the most common, and potentially the most annoying, sound."));
-
   label = gtk_label_new_with_mnemonic (_("Game"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), cpage, label);
 
@@ -621,7 +599,7 @@ load_properties (void)
 {
   gchar *cname = NULL;
   gint i;
-  gchar *bgcolour;
+  gchar *bgcolour, *config;
 
   load_keys ();
 
@@ -638,10 +616,13 @@ load_properties (void)
 
   properties.selected_config = 0;
   for (i = 0; i < num_game_configs (); ++i) {
-    if (!strcmp (cname, game_config_name (i))) {
+    config = game_config_name (i);
+    if (!strcmp (cname, config)) {
+      g_free (config);
       properties.selected_config = i;
       break;
     }
+    g_free (config);
   }
   g_free (cname);
 
@@ -652,8 +633,6 @@ load_properties (void)
 						        NULL);
   properties.sound = games_conf_get_boolean (KEY_PREFERENCES_GROUP,
                                              KEY_ENABLE_SOUND, NULL);
-  properties.splats = games_conf_get_boolean (KEY_PREFERENCES_GROUP,
-                                              KEY_ENABLE_SPLATS, NULL);
   properties.show_toolbar = games_conf_get_boolean (KEY_PREFERENCES_GROUP,
                                                     KEY_SHOW_TOOLBAR, NULL);
 
@@ -720,12 +699,6 @@ conf_set_enable_sound (gboolean value)
   games_conf_set_boolean (KEY_PREFERENCES_GROUP, KEY_ENABLE_SOUND, value);
 }
 
-void
-conf_set_enable_splats (gboolean value)
-{
-  games_conf_set_boolean (KEY_PREFERENCES_GROUP, KEY_ENABLE_SPLATS, value);
-}
-
 void
 conf_set_show_toolbar (gboolean value)
 {
@@ -753,17 +726,21 @@ gboolean
 save_properties (void)
 {
   gint i;
+  gchar *config;
 
   for (i = 0; i < 12; i++) {
     conf_set_control_key (i, properties.keys[i]);
   }
 
   conf_set_theme (properties.themename);
-  conf_set_configuration (game_config_name (properties.selected_config));
+
+  config = game_config_name (properties.selected_config);
+  conf_set_configuration (config);
+  g_free (config);
+
   conf_set_use_safe_moves (properties.safe_moves);
   conf_set_use_super_safe_moves (properties.super_safe_moves);
   conf_set_enable_sound (properties.sound);
-  conf_set_enable_splats (properties.splats);
 
   return TRUE;
 }
@@ -817,22 +794,6 @@ properties_sound (void)
 }
 
 
-/**
- * properties_splats
- *
- * Description:
- * returns splat setting
- *
- * Returns:
- * TRUE if splats are selected
- **/
-gboolean
-properties_splats (void)
-{
-  return properties.splats;
-}
-
-
 /**
  * properties_show_toolbar
  *
